@@ -42,7 +42,7 @@ test_summarizeOverlaps_Union_paired <- function()
     ga <- GAlignments("chr1", 1L, "10M4N11M", strand("+"))
     ga1 <- GAlignments("chr1", 1L, "10M", strand("+"))
     ga2 <- GAlignments("chr1", 15L, "11M", strand("-"))
-    galp <- GAlignmentPairs(ga1, ga2, TRUE)
+    galp <- GAlignmentPairs(ga1, ga2)
     ann <- GRanges("chr1", IRanges(c(1, 5, 12, 20), c(25, 20, 14, 30)), "+")
 
     res_ga <- summarizeOverlaps(ann[1], ga, mode)
@@ -95,7 +95,7 @@ test_summarizeOverlaps_IntersectionStrict_paired <- function()
     ga <- GAlignments("chr1", 10L, "6M4N6M", strand("+"))
     ga1 <- GAlignments("chr1", 10L, "6M", strand("+"))
     ga2 <- GAlignments("chr1", 20L, "6M", strand("-"))
-    galp <- GAlignmentPairs(ga1, ga2, TRUE)
+    galp <- GAlignmentPairs(ga1, ga2)
     ann <- GRanges("chr1", IRanges(c(1, 1, 20), c(30, 15, 30)), "+")
 
     res_ga <- summarizeOverlaps(ann[1], ga, mode)
@@ -164,7 +164,7 @@ test_summarizeOverlaps_IntersectionNotEmpty_paired <- function()
     ga <- GAlignments("chr1", 10L, "6M4N6M", strand("+"))
     ga1 <- GAlignments("chr1", 10L, "6M", strand("+"))
     ga2 <- GAlignments("chr1", 20L, "6M", strand("-"))
-    galp <- GAlignmentPairs(ga1, ga2, TRUE)
+    galp <- GAlignmentPairs(ga1, ga2)
     ann <- GRanges("chr1", IRanges(c(1, 1, 20), c(30, 15, 30)), "+")
 
     ## single-end, junctions
